@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp ();
 
-our $VERSION = '3.33_05';
+our $VERSION = '3.33_06';
 
 BEGIN { *DEBUG = sub () {0} unless defined &DEBUG; }   # set DEBUG level
 
@@ -14,7 +14,11 @@ our $SLEEPY = 1 if !defined $SLEEPY and $^O =~ /mswin|mac/i;
 
 our $MAX_VERSION_WITHIN ||= 60;
 my $IS_CASE_INSENSITIVE     = -e uc __FILE__ && -e lc __FILE__;
-my @DEFAULT_FILE_EXTENSIONS = ('', '.pod', '.pm', '.pl', 'plx');
+
+# This specifies the default order for considering filenames
+# that might have pod. You can override this default order
+# with the _file_extensions() method. Note the leading _ :-)
+my @DEFAULT_FILE_EXTENSIONS = ('.pod', '', '.pm', '.pl', 'plx');
 
 #############################################################################
 
@@ -44,7 +48,7 @@ sub init {
   $self->inc(1);
   $self->recurse(1);
   $self->verbose(DEBUG);
-  $self->file_extensions(@DEFAULT_FILE_EXTENSIONS);
+  $self->_file_extensions(@DEFAULT_FILE_EXTENSIONS);
   return $self;
 }
 
@@ -263,7 +267,8 @@ sub _path2modname {
   while(@m
     and defined($x = lc( $m[0] ))
     and(  $x eq 'site_perl'
-       or($x eq 'pod' and @m == 1 and $shortname =~ m{^perl.*\.pod$}s )
+       # or($x eq 'pod' and @m == 1 and $shortname =~ m{^perl.*\.pod$}s )
+       or($x eq 'pod' and @m == 1 and $shortname =~ m{^perl.*(\.pod)?$}s )
        or $x =~ m{\\d+\\.z\\d+([_.]?\\d+)?}  # if looks like a vernum
        or $x eq lc( $Config::Config{'archname'} )
   )) { shift @m }
@@ -337,13 +342,28 @@ sub _recurse_dir {
       return
     }
 
-    # Load all items; put no extension before .pod before .pm before .plx?.
+    # We want to get the files in the directory sorted in the order
+    # of filename extensions given via the _file_extensions() method.
+
+    # -------------------------------------------------------
+    # This block is how the order used to be done, but it
+    # hardcoded the order of filename extensions, and which
+    # ones we're interested in.
+    #
+    # my @items = map { $_->[0] }
+    #   sort { $a->[1] cmp $b->[1] || $b->[2] cmp $a->[2] }
+    #   map {
+    #     (my $t = $_) =~ s/[.]p(m|lx?|od)\z//;
+    #     [$_, $t, lc($1 || 'z') ]
+    #   } readdir(INDIR);
+    # -------------------------------------------------------
+
+    my $sort_order = $self->{sort_order};
     my @items = map { $_->[0] }
-      sort { $a->[1] cmp $b->[1] || $b->[2] cmp $a->[2] }
-      map {
-        (my $t = $_) =~ s/[.]p(m|lx?|od)\z//;
-        [$_, $t, lc($1 || 'z') ]
-      } readdir(INDIR);
+                sort { $a->[1] <=> $b->[1] }
+                map { [$_, $sort_order->{/([.][^.]+)\z/ ? $1 : ''} // 'Inf' ] }
+                readdir(INDIR);
+
     closedir(INDIR);
 
     push @$modname_bits, $dir_bare unless $dir_bare eq '';
@@ -588,7 +608,7 @@ sub find {
     my $fullname = File::Spec->catfile( $dir, @parts );
     print "Filename is now $fullname\n" if $verbose;
 
-    foreach my $ext ($self->file_extensions) {
+    foreach my $ext ($self->_file_extensions) {
       my $fullext = $fullname . $ext;
       if ( -f $fullext and $self->contains_pod($fullext) ) {
         print "FOUND: $fullext\n" if $verbose;
@@ -658,10 +678,21 @@ sub contains_pod {
 
 #==========================================================================
 
-sub file_extensions {
+sub _file_extensions {
   my $self = shift;
 
   if (@_ > 0) {
+    my $sort_order = {};
+    my $index      = 0;
+
+    # Elsewhere we want to sort files into the order specified in
+    # this list of filename extensions. So we build a hash,
+    # mapping extensions to sort order (ascending). This might
+    # include the empty string, for "no filename extension"
+    foreach my $ending (@_) {
+        $sort_order->{$ending} = $index++;
+    }
+    $self->{sort_order} = $sort_order;
     $self->{file_extensions} = [@_];
   }
   return @{ $self->{file_extensions} };
@@ -669,7 +700,7 @@ sub file_extensions {
 
 sub _file_extensions_re {
   my $self = shift;
-  return join('|', map { "\Q$_\E" } $self->file_extensions);
+  return join('|', map { "\Q$_\E" } $self->_file_extensions);
 }
 
 #==========================================================================
@@ -894,20 +925,6 @@ include it in case it might prove useful for someone somewhere.
 and usually dir_prefix.)
 
 
-=item $search->file_extensions( I<list-of-strings> );
-
-Used to query or override the list of filename extensions
-considered when the C<survey> and C<find> methods are
-looking for files containing pod.
-
-The default list of extensions is:
-
- '', '.pod', '.pm', '.pl', 'plx'
-
-Note that the order of the filename extensions is relevant:
-a C<.pod> file will be taken ahead of the associated C<.pm> file
-by C<find>.
-
 =item $search->progress( I<some-progress-object> );
 
 If you set a value for this attribute, the value is expected
